@@ -24,9 +24,21 @@
 #include <stdio.h>
 #include <string.h>
 
+#ifndef ALIGNED
+#ifdef _MSC_VER
+#define ALIGNED(x) __declspec(align(x))
+#else
+#define ALIGNED(x) __attribute__((aligned(x)))
+#endif
+#endif
+
 #ifndef STDCALL
+#ifdef _MSC_VER
+#define STDCALL __stdcall
+#else
 #define STDCALL
 #endif
+#endif
 
 #ifndef FASTCALL
 #ifdef __MINGW32__
@@ -183,12 +195,16 @@ static INLINE int StateCheckRetrieveHeader(FILE *fp, const char *name, int *vers
 // Terrible, but I'm not sure how to do the equivalent in inline
 #ifdef HAVE_C99_VARIADIC_MACROS
 #define AddString(s, ...) \
-   sprintf(s, __VA_ARGS__); \
-   s += strlen(s)
+   { \
+      sprintf(s, __VA_ARGS__); \
+      s += strlen(s); \
+   }
 #else
 #define AddString(s, r...) \
-   sprintf(s, ## r); \
-   s += strlen(s)
+   { \
+      sprintf(s, ## r); \
+      s += strlen(s); \
+   }
 #endif
 
 //////////////////////////////////////////////////////////////////////////////
