@@ -29,118 +29,118 @@ cartridge_struct *CartridgeArea;
 // Dummy/No Cart Functions
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL DummyCs0ReadByte(UNUSED u32 addr)
+static u8 FASTCALL DummyCs0ReadByte(UNUSED u32 addr)
 {
    return 0xFF;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL DummyCs0ReadWord(UNUSED u32 addr)
+static u16 FASTCALL DummyCs0ReadWord(UNUSED u32 addr)
 {
    return 0xFFFF;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL DummyCs0ReadLong(UNUSED u32 addr)
+static u32 FASTCALL DummyCs0ReadLong(UNUSED u32 addr)
 {
    return 0xFFFFFFFF;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DummyCs0WriteByte(UNUSED u32 addr, UNUSED u8 val)
+static void FASTCALL DummyCs0WriteByte(UNUSED u32 addr, UNUSED u8 val)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DummyCs0WriteWord(UNUSED u32 addr, UNUSED u16 val)
+static void FASTCALL DummyCs0WriteWord(UNUSED u32 addr, UNUSED u16 val)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DummyCs0WriteLong(UNUSED u32 addr, UNUSED u32 val)
+static void FASTCALL DummyCs0WriteLong(UNUSED u32 addr, UNUSED u32 val)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL DummyCs1ReadByte(UNUSED u32 addr)
+static u8 FASTCALL DummyCs1ReadByte(UNUSED u32 addr)
 {
    return 0xFF;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL DummyCs1ReadWord(UNUSED u32 addr)
+static u16 FASTCALL DummyCs1ReadWord(UNUSED u32 addr)
 {
    return 0xFFFF;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL DummyCs1ReadLong(UNUSED u32 addr)
+static u32 FASTCALL DummyCs1ReadLong(UNUSED u32 addr)
 {
    return 0xFFFFFFFF;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DummyCs1WriteByte(UNUSED u32 addr, UNUSED u8 val)
+static void FASTCALL DummyCs1WriteByte(UNUSED u32 addr, UNUSED u8 val)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DummyCs1WriteWord(UNUSED u32 addr, UNUSED u16 val)
+static void FASTCALL DummyCs1WriteWord(UNUSED u32 addr, UNUSED u16 val)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DummyCs1WriteLong(UNUSED u32 addr, UNUSED u32 val)
+static void FASTCALL DummyCs1WriteLong(UNUSED u32 addr, UNUSED u32 val)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL DummyCs2ReadByte(UNUSED u32 addr)
+static u8 FASTCALL DummyCs2ReadByte(UNUSED u32 addr)
 {
    return 0xFF;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL DummyCs2ReadWord(UNUSED u32 addr)
+static u16 FASTCALL DummyCs2ReadWord(UNUSED u32 addr)
 {
    return 0xFFFF;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL DummyCs2ReadLong(UNUSED u32 addr)
+static u32 FASTCALL DummyCs2ReadLong(UNUSED u32 addr)
 {
    return 0xFFFFFFFF;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DummyCs2WriteByte(UNUSED u32 addr, UNUSED u8 val)
+static void FASTCALL DummyCs2WriteByte(UNUSED u32 addr, UNUSED u8 val)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DummyCs2WriteWord(UNUSED u32 addr, UNUSED u16 val)
+static void FASTCALL DummyCs2WriteWord(UNUSED u32 addr, UNUSED u16 val)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DummyCs2WriteLong(UNUSED u32 addr, UNUSED u32 val)
+static void FASTCALL DummyCs2WriteLong(UNUSED u32 addr, UNUSED u32 val)
 {
 }
 
@@ -171,7 +171,7 @@ u8 flbuf1[128];
 
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL FlashCs0ReadByte(u32 addr)
+static u8 FASTCALL FlashCs0ReadByte(u32 addr)
 {
   flashstate* state;
   u8* reg;
@@ -205,21 +205,21 @@ u8 FASTCALL FlashCs0ReadByte(u32 addr)
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL FlashCs0ReadWord(u32 addr)
+static u16 FASTCALL FlashCs0ReadWord(u32 addr)
 {
   return ((u16)(FlashCs0ReadByte(addr) << 8) | (u16)(FlashCs0ReadByte(addr+1)));
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL FlashCs0ReadLong(u32 addr)
+static u32 FASTCALL FlashCs0ReadLong(u32 addr)
 {
   return ((u32)FlashCs0ReadWord(addr) << 16) |(u32) FlashCs0ReadWord(addr + 2);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL FlashCs0WriteByte(u32 addr, u8 val)
+static void FASTCALL FlashCs0WriteByte(u32 addr, u8 val)
 {
   flashstate* state;
   u8* reg;
@@ -303,7 +303,7 @@ void FASTCALL FlashCs0WriteByte(u32 addr, u8 val)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL FlashCs0WriteWord(u32 addr, u16 val)
+static void FASTCALL FlashCs0WriteWord(u32 addr, u16 val)
 {
   FlashCs0WriteByte(addr, (u8)(val >> 8));
   FlashCs0WriteByte(addr + 1, (u8)(val & 0xff));
@@ -311,7 +311,7 @@ void FASTCALL FlashCs0WriteWord(u32 addr, u16 val)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL FlashCs0WriteLong(u32 addr, u32 val)
+static void FASTCALL FlashCs0WriteLong(u32 addr, u32 val)
 {
   FlashCs0WriteWord(addr, (u16)(val >> 16));
   FlashCs0WriteWord(addr + 2, (u16)(val & 0xffff));
@@ -319,7 +319,7 @@ void FASTCALL FlashCs0WriteLong(u32 addr, u32 val)
 
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL AR4MCs0ReadByte(u32 addr)
+static u8 FASTCALL AR4MCs0ReadByte(u32 addr)
 {
    addr &= 0x1FFFFFF;
 
@@ -356,7 +356,7 @@ u8 FASTCALL AR4MCs0ReadByte(u32 addr)
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL AR4MCs0ReadWord(u32 addr)
+static u16 FASTCALL AR4MCs0ReadWord(u32 addr)
 {
    addr &= 0x1FFFFFF;
 
@@ -404,7 +404,7 @@ u16 FASTCALL AR4MCs0ReadWord(u32 addr)
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL AR4MCs0ReadLong(u32 addr)
+static u32 FASTCALL AR4MCs0ReadLong(u32 addr)
 {
    addr &= 0x1FFFFFF;
 
@@ -452,7 +452,7 @@ u32 FASTCALL AR4MCs0ReadLong(u32 addr)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL AR4MCs0WriteByte(u32 addr, u8 val)
+static void FASTCALL AR4MCs0WriteByte(u32 addr, u8 val)
 {
    addr &= 0x1FFFFFF;
 
@@ -487,7 +487,7 @@ void FASTCALL AR4MCs0WriteByte(u32 addr, u8 val)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL AR4MCs0WriteWord(u32 addr, u16 val)
+static void FASTCALL AR4MCs0WriteWord(u32 addr, u16 val)
 {
    addr &= 0x1FFFFFF;
 
@@ -522,7 +522,7 @@ void FASTCALL AR4MCs0WriteWord(u32 addr, u16 val)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL AR4MCs0WriteLong(u32 addr, u32 val)
+static void FASTCALL AR4MCs0WriteLong(u32 addr, u32 val)
 {
    addr &= 0x1FFFFFF;
 
@@ -559,7 +559,7 @@ void FASTCALL AR4MCs0WriteLong(u32 addr, u32 val)
 // 8 Mbit Dram
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL DRAM8MBITCs0ReadByte(u32 addr)
+static u8 FASTCALL DRAM8MBITCs0ReadByte(u32 addr)
 {
    addr &= 0x1FFFFFF;
 
@@ -578,7 +578,7 @@ u8 FASTCALL DRAM8MBITCs0ReadByte(u32 addr)
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL DRAM8MBITCs0ReadWord(u32 addr)
+static u16 FASTCALL DRAM8MBITCs0ReadWord(u32 addr)
 {
    addr &= 0x1FFFFFF;
 
@@ -597,7 +597,7 @@ u16 FASTCALL DRAM8MBITCs0ReadWord(u32 addr)
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL DRAM8MBITCs0ReadLong(u32 addr)
+static u32 FASTCALL DRAM8MBITCs0ReadLong(u32 addr)
 {
    addr &= 0x1FFFFFF;
 
@@ -616,7 +616,7 @@ u32 FASTCALL DRAM8MBITCs0ReadLong(u32 addr)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DRAM8MBITCs0WriteByte(u32 addr, u8 val)
+static void FASTCALL DRAM8MBITCs0WriteByte(u32 addr, u8 val)
 {
    addr &= 0x1FFFFFF;
 
@@ -635,7 +635,7 @@ void FASTCALL DRAM8MBITCs0WriteByte(u32 addr, u8 val)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DRAM8MBITCs0WriteWord(u32 addr, u16 val)
+static void FASTCALL DRAM8MBITCs0WriteWord(u32 addr, u16 val)
 {
    addr &= 0x1FFFFFF;
 
@@ -654,7 +654,7 @@ void FASTCALL DRAM8MBITCs0WriteWord(u32 addr, u16 val)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DRAM8MBITCs0WriteLong(u32 addr, u32 val)
+static void FASTCALL DRAM8MBITCs0WriteLong(u32 addr, u32 val)
 {
    addr &= 0x1FFFFFF;
 
@@ -675,7 +675,7 @@ void FASTCALL DRAM8MBITCs0WriteLong(u32 addr, u32 val)
 // 32 Mbit Dram
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL DRAM32MBITCs0ReadByte(u32 addr)
+static u8 FASTCALL DRAM32MBITCs0ReadByte(u32 addr)
 {
    addr &= 0x1FFFFFF;
 
@@ -695,7 +695,7 @@ u8 FASTCALL DRAM32MBITCs0ReadByte(u32 addr)
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL DRAM32MBITCs0ReadWord(u32 addr)
+static u16 FASTCALL DRAM32MBITCs0ReadWord(u32 addr)
 {
    addr &= 0x1FFFFFF;
 
@@ -715,7 +715,7 @@ u16 FASTCALL DRAM32MBITCs0ReadWord(u32 addr)
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL DRAM32MBITCs0ReadLong(u32 addr)
+static u32 FASTCALL DRAM32MBITCs0ReadLong(u32 addr)
 {
    addr &= 0x1FFFFFF;
 
@@ -735,7 +735,7 @@ u32 FASTCALL DRAM32MBITCs0ReadLong(u32 addr)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DRAM32MBITCs0WriteByte(u32 addr, u8 val)
+static void FASTCALL DRAM32MBITCs0WriteByte(u32 addr, u8 val)
 {
    addr &= 0x1FFFFFF;
 
@@ -754,7 +754,7 @@ void FASTCALL DRAM32MBITCs0WriteByte(u32 addr, u8 val)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DRAM32MBITCs0WriteWord(u32 addr, u16 val)
+static void FASTCALL DRAM32MBITCs0WriteWord(u32 addr, u16 val)
 {
    addr &= 0x1FFFFFF;
 
@@ -773,7 +773,7 @@ void FASTCALL DRAM32MBITCs0WriteWord(u32 addr, u16 val)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL DRAM32MBITCs0WriteLong(u32 addr, u32 val)
+static void FASTCALL DRAM32MBITCs0WriteLong(u32 addr, u32 val)
 {
    addr &= 0x1FFFFFF;
 
@@ -794,42 +794,42 @@ void FASTCALL DRAM32MBITCs0WriteLong(u32 addr, u32 val)
 // 4 Mbit Backup Ram
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL BUP4MBITCs1ReadByte(u32 addr)
+static u8 FASTCALL BUP4MBITCs1ReadByte(u32 addr)
 {
    return T1ReadByte(CartridgeArea->bupram, addr & 0xFFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL BUP4MBITCs1ReadWord(u32 addr)
+static u16 FASTCALL BUP4MBITCs1ReadWord(u32 addr)
 {
    return T1ReadWord(CartridgeArea->bupram, addr & 0xFFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL BUP4MBITCs1ReadLong(u32 addr)
+static u32 FASTCALL BUP4MBITCs1ReadLong(u32 addr)
 {
    return T1ReadLong(CartridgeArea->bupram, addr & 0xFFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BUP4MBITCs1WriteByte(u32 addr, u8 val)
+static void FASTCALL BUP4MBITCs1WriteByte(u32 addr, u8 val)
 {
    T1WriteByte(CartridgeArea->bupram, addr & 0xFFFFF, val);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BUP4MBITCs1WriteWord(u32 addr, u16 val)
+static void FASTCALL BUP4MBITCs1WriteWord(u32 addr, u16 val)
 {
    T1WriteWord(CartridgeArea->bupram, addr & 0xFFFFF, val);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BUP4MBITCs1WriteLong(u32 addr, u32 val)
+static void FASTCALL BUP4MBITCs1WriteLong(u32 addr, u32 val)
 {
    T1WriteLong(CartridgeArea->bupram, addr & 0xFFFFF, val);
 }
@@ -838,42 +838,42 @@ void FASTCALL BUP4MBITCs1WriteLong(u32 addr, u32 val)
 // 8 Mbit Backup Ram
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL BUP8MBITCs1ReadByte(u32 addr)
+static u8 FASTCALL BUP8MBITCs1ReadByte(u32 addr)
 {
    return T1ReadByte(CartridgeArea->bupram, addr & 0x1FFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL BUP8MBITCs1ReadWord(u32 addr)
+static u16 FASTCALL BUP8MBITCs1ReadWord(u32 addr)
 {
    return T1ReadWord(CartridgeArea->bupram, addr & 0x1FFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL BUP8MBITCs1ReadLong(u32 addr)
+static u32 FASTCALL BUP8MBITCs1ReadLong(u32 addr)
 {
    return T1ReadLong(CartridgeArea->bupram, addr & 0x1FFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BUP8MBITCs1WriteByte(u32 addr, u8 val)
+static void FASTCALL BUP8MBITCs1WriteByte(u32 addr, u8 val)
 {
    T1WriteByte(CartridgeArea->bupram, addr & 0x1FFFFF, val);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BUP8MBITCs1WriteWord(u32 addr, u16 val)
+static void FASTCALL BUP8MBITCs1WriteWord(u32 addr, u16 val)
 {
    T1WriteWord(CartridgeArea->bupram, addr & 0x1FFFFF, val);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BUP8MBITCs1WriteLong(u32 addr, u32 val)
+static void FASTCALL BUP8MBITCs1WriteLong(u32 addr, u32 val)
 {
    T1WriteLong(CartridgeArea->bupram, addr & 0x1FFFFF, val);
 }
@@ -882,42 +882,42 @@ void FASTCALL BUP8MBITCs1WriteLong(u32 addr, u32 val)
 // 16 Mbit Backup Ram
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL BUP16MBITCs1ReadByte(u32 addr)
+static u8 FASTCALL BUP16MBITCs1ReadByte(u32 addr)
 {
    return T1ReadByte(CartridgeArea->bupram, addr & 0x3FFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL BUP16MBITCs1ReadWord(u32 addr)
+static u16 FASTCALL BUP16MBITCs1ReadWord(u32 addr)
 {
    return T1ReadWord(CartridgeArea->bupram, addr & 0x3FFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL BUP16MBITCs1ReadLong(u32 addr)
+static u32 FASTCALL BUP16MBITCs1ReadLong(u32 addr)
 {
    return T1ReadLong(CartridgeArea->bupram, addr & 0x3FFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BUP16MBITCs1WriteByte(u32 addr, u8 val)
+static void FASTCALL BUP16MBITCs1WriteByte(u32 addr, u8 val)
 {
    T1WriteByte(CartridgeArea->bupram, addr & 0x3FFFFF, val);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BUP16MBITCs1WriteWord(u32 addr, u16 val)
+static void FASTCALL BUP16MBITCs1WriteWord(u32 addr, u16 val)
 {
    T1WriteWord(CartridgeArea->bupram, addr & 0x3FFFFF, val);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BUP16MBITCs1WriteLong(u32 addr, u32 val)
+static void FASTCALL BUP16MBITCs1WriteLong(u32 addr, u32 val)
 {
    T1WriteLong(CartridgeArea->bupram, addr & 0x3FFFFF, val);
 }
@@ -926,42 +926,42 @@ void FASTCALL BUP16MBITCs1WriteLong(u32 addr, u32 val)
 // 32 Mbit Backup Ram
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL BUP32MBITCs1ReadByte(u32 addr)
+static u8 FASTCALL BUP32MBITCs1ReadByte(u32 addr)
 {
    return T1ReadByte(CartridgeArea->bupram, addr & 0x7FFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL BUP32MBITCs1ReadWord(u32 addr)
+static u16 FASTCALL BUP32MBITCs1ReadWord(u32 addr)
 {
    return T1ReadWord(CartridgeArea->bupram, addr & 0x7FFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL BUP32MBITCs1ReadLong(u32 addr)
+static u32 FASTCALL BUP32MBITCs1ReadLong(u32 addr)
 {
    return T1ReadLong(CartridgeArea->bupram, addr & 0x7FFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BUP32MBITCs1WriteByte(u32 addr, u8 val)
+static void FASTCALL BUP32MBITCs1WriteByte(u32 addr, u8 val)
 {
    T1WriteByte(CartridgeArea->bupram, addr & 0x7FFFFF, val);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BUP32MBITCs1WriteWord(u32 addr, u16 val)
+static void FASTCALL BUP32MBITCs1WriteWord(u32 addr, u16 val)
 {
    T1WriteWord(CartridgeArea->bupram, addr & 0x7FFFFF, val);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BUP32MBITCs1WriteLong(u32 addr, u32 val)
+static void FASTCALL BUP32MBITCs1WriteLong(u32 addr, u32 val)
 {
    T1WriteLong(CartridgeArea->bupram, addr & 0x7FFFFF, val);
 }
@@ -970,42 +970,42 @@ void FASTCALL BUP32MBITCs1WriteLong(u32 addr, u32 val)
 // 16 Mbit Rom
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL ROM16MBITCs0ReadByte(u32 addr)
+static u8 FASTCALL ROM16MBITCs0ReadByte(u32 addr)
 {
    return T1ReadByte(CartridgeArea->rom, addr & 0x1FFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL ROM16MBITCs0ReadWord(u32 addr)
+static u16 FASTCALL ROM16MBITCs0ReadWord(u32 addr)
 {
    return T1ReadWord(CartridgeArea->rom, addr & 0x1FFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL ROM16MBITCs0ReadLong(u32 addr)
+static u32 FASTCALL ROM16MBITCs0ReadLong(u32 addr)
 {
    return T1ReadLong(CartridgeArea->rom, addr & 0x1FFFFF);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL ROM16MBITCs0WriteByte(u32 addr, u8 val)
+static void FASTCALL ROM16MBITCs0WriteByte(u32 addr, u8 val)
 {
    T1WriteByte(CartridgeArea->rom, addr & 0x1FFFFF, val);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL ROM16MBITCs0WriteWord(u32 addr, u16 val)
+static void FASTCALL ROM16MBITCs0WriteWord(u32 addr, u16 val)
 {
    T1WriteWord(CartridgeArea->rom, addr & 0x1FFFFF, val);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL ROM16MBITCs0WriteLong(u32 addr, u32 val)
+static void FASTCALL ROM16MBITCs0WriteLong(u32 addr, u32 val)
 {
    T1WriteLong(CartridgeArea->rom, addr & 0x1FFFFF, val);
 }
@@ -1014,7 +1014,7 @@ void FASTCALL ROM16MBITCs0WriteLong(u32 addr, u32 val)
 // Sega Saturn Modem(Japanese)
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL JapModemCs0ReadByte(u32 addr)
+static u8 FASTCALL JapModemCs0ReadByte(u32 addr)
 {
    if (addr & 0x1)
       return 0xA5;
@@ -1024,35 +1024,35 @@ u8 FASTCALL JapModemCs0ReadByte(u32 addr)
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL JapModemCs0ReadWord(UNUSED u32 addr)
+static u16 FASTCALL JapModemCs0ReadWord(UNUSED u32 addr)
 {
    return 0xFFA5;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL JapModemCs0ReadLong(UNUSED u32 addr)
+static u32 FASTCALL JapModemCs0ReadLong(UNUSED u32 addr)
 {
    return 0xFFA5FFA5;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL JapModemCs1ReadByte(UNUSED u32 addr)
+static u8 FASTCALL JapModemCs1ReadByte(UNUSED u32 addr)
 {
    return 0xA5;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL JapModemCs1ReadWord(UNUSED u32 addr)
+static u16 FASTCALL JapModemCs1ReadWord(UNUSED u32 addr)
 {
    return 0xA5A5;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL JapModemCs1ReadLong(UNUSED u32 addr)
+static u32 FASTCALL JapModemCs1ReadLong(UNUSED u32 addr)
 {
    return 0xA5A5A5A5;
 }
