@@ -1108,6 +1108,8 @@ int YabSaveState(const char *filename)
 
    fclose(fp);
 
+   OSDPushMessage(OSDMSG_STATUS, 150, "STATE SAVED");
+
    return 0;
 }
 
@@ -1196,13 +1198,13 @@ int YabLoadState(const char *filename)
 
    // Verify version here
 
-   ScspMuteAudio();
+   ScspMuteAudio(SCSP_MUTE_SYSTEM);
    
    if (StateCheckRetrieveHeader(fp, "CART", &version, &chunksize) != 0)
    {
       fclose(fp);
       // Revert back to old state here
-      ScspUnMuteAudio();
+      ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
       return -3;
    }
    CartLoadState(fp, version, chunksize);
@@ -1211,7 +1213,7 @@ int YabLoadState(const char *filename)
    {
       fclose(fp);
       // Revert back to old state here
-      ScspUnMuteAudio();
+      ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
       return -3;
    }
    Cs2LoadState(fp, version, chunksize);
@@ -1220,7 +1222,7 @@ int YabLoadState(const char *filename)
    {
       fclose(fp);
       // Revert back to old state here
-      ScspUnMuteAudio();
+      ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
       return -3;
    }
    SH2LoadState(MSH2, fp, version, chunksize);
@@ -1229,7 +1231,7 @@ int YabLoadState(const char *filename)
    {
       fclose(fp);
       // Revert back to old state here
-      ScspUnMuteAudio();
+      ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
       return -3;
    }
    SH2LoadState(SSH2, fp, version, chunksize);
@@ -1238,7 +1240,7 @@ int YabLoadState(const char *filename)
    {
       fclose(fp);
       // Revert back to old state here
-      ScspUnMuteAudio();
+      ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
       return -3;
    }
    SoundLoadState(fp, version, chunksize);
@@ -1247,7 +1249,7 @@ int YabLoadState(const char *filename)
    {
       fclose(fp);
       // Revert back to old state here
-      ScspUnMuteAudio();
+      ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
       return -3;
    }
    ScuLoadState(fp, version, chunksize);
@@ -1256,7 +1258,7 @@ int YabLoadState(const char *filename)
    {
       fclose(fp);
       // Revert back to old state here
-      ScspUnMuteAudio();
+      ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
       return -3;
    }
    SmpcLoadState(fp, version, chunksize);
@@ -1265,7 +1267,7 @@ int YabLoadState(const char *filename)
    {
       fclose(fp);
       // Revert back to old state here
-      ScspUnMuteAudio();
+      ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
       return -3;
    }
    Vdp1LoadState(fp, version, chunksize);
@@ -1274,7 +1276,7 @@ int YabLoadState(const char *filename)
    {
       fclose(fp);
       // Revert back to old state here
-      ScspUnMuteAudio();
+      ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
       return -3;
    }
    Vdp2LoadState(fp, version, chunksize);
@@ -1283,7 +1285,7 @@ int YabLoadState(const char *filename)
    {
       fclose(fp);
       // Revert back to old state here
-      ScspUnMuteAudio();
+      ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
       return -3;
    }
    // Other data
@@ -1339,7 +1341,10 @@ int YabLoadState(const char *filename)
    
    fclose(fp);
 
-   ScspUnMuteAudio();
+   ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
+
+   OSDPushMessage(OSDMSG_STATUS, 150, "STATE LOADED");
+
    return 0;
 }
 
@@ -1348,6 +1353,10 @@ int YabLoadState(const char *filename)
 int YabSaveStateSlot(const char *dirpath, u8 slot)
 {
    char filename[512];
+
+   if (cdip == NULL)
+      return -1;
+
 #ifdef WIN32
    sprintf(filename, "%s\\%s_%03d.yss", dirpath, cdip->itemnum, slot);
 #else
@@ -1361,6 +1370,10 @@ int YabSaveStateSlot(const char *dirpath, u8 slot)
 int YabLoadStateSlot(const char *dirpath, u8 slot)
 {
    char filename[512];
+
+   if (cdip == NULL)
+      return -1;
+
 #ifdef WIN32
    sprintf(filename, "%s\\%s_%03d.yss", dirpath, cdip->itemnum, slot);
 #else
