@@ -24,6 +24,14 @@
 #include "UISettings.h"
 #include "UIBackupRam.h"
 #include "UICheats.h"
+#include "UICheatSearch.h"
+#include "UIDebugSH2.h"
+#include "UIDebugVDP1.h"
+#include "UIDebugVDP2.h"
+#include "UIDebugM68K.h"
+#include "UIDebugSCUDSP.h"
+#include "UIDebugSCSP.h"
+#include "UIMemoryTransfer.h"
 #include "UIAbout.h"
 #include "../YabauseGL.h"
 #include "../QtYabause.h"
@@ -61,6 +69,10 @@ UIYabause::UIYabause( QWidget* parent )
 	: QMainWindow( parent )
 {
 	mInit = false;
+	searchResults = NULL;
+	numSearchResults = 0;
+	searchType = 0;
+
 	// setup dialog
 	setupUi( this );
 	toolBar->insertAction( aFileSettings, mFileSaveState->menuAction() );
@@ -106,6 +118,11 @@ UIYabause::UIYabause( QWidget* parent )
 	connect( mYabauseThread, SIGNAL( reset() ), this, SLOT( reset() ) );
 	// retranslate widgets
 	QtYabause::retranslateWidget( this );
+
+	QList<QAction *> actionList = menubar->actions();
+	for(int i = 0;i < actionList.size();i++) {
+		addAction(actionList.at(i));
+	}
 }
 
 void UIYabause::showEvent( QShowEvent* e )
@@ -116,8 +133,13 @@ void UIYabause::showEvent( QShowEvent* e )
 	{
 		LogStart();
 		LogChangeOutput( DEBUG_CALLBACK, (char*)qAppendLog );
-		aEmulationRun->trigger();
 		VolatileSettings* vs = QtYabause::volatileSettings();
+		if ( vs->value( "View/Menubar" ).toInt() == 2 )
+			menubar->hide();
+		if ( vs->value( "View/Toolbar" ).toInt() == 2 )
+			toolBar->hide();
+		if ( vs->value( "autostart" ).toBool() )
+			aEmulationRun->trigger();
 		aEmulationFrameSkipLimiter->setChecked( vs->value( "General/EnableFrameSkipLimiter" ).toBool() );
 		aViewFPS->setChecked( vs->value( "General/ShowFPS" ).toBool() );
 		mInit = true;
@@ -178,6 +200,11 @@ void UIYabause::fullscreenRequested( bool f )
 #ifdef USE_UNIFIED_TITLE_TOOLBAR
 		setUnifiedTitleAndToolBarOnMac( true );
 #endif
+		VolatileSettings* vs = QtYabause::volatileSettings();
+		if ( vs->value( "View/Menubar" ).toInt() == 1 )
+			menubar->show();
+		if ( vs->value( "View/Toolbar" ).toInt() == 1 )
+			toolBar->show();
 	}
 	else if ( !isFullScreen() && f )
 	{
@@ -185,6 +212,11 @@ void UIYabause::fullscreenRequested( bool f )
 		setUnifiedTitleAndToolBarOnMac( false );
 #endif
 		showFullScreen();
+		VolatileSettings* vs = QtYabause::volatileSettings();
+		if ( vs->value( "View/Menubar" ).toInt() == 1 )
+			menubar->hide();
+		if ( vs->value( "View/Toolbar" ).toInt() == 1 )
+			toolBar->hide();
 	}
 	if ( aViewFullscreen->isChecked() != f )
 		aViewFullscreen->setChecked( f );
@@ -219,7 +251,7 @@ void UIYabause::refreshStatesActions()
 	// get states files of this game
 	const QString serial = QtYabause::getCurrentCdSerial();
 	const QString mask = QString( "%1_*.yss" ).arg( serial );
-	const QString statesPath = QtYabause::volatileSettings()->value( "General/SaveStates", QApplication::applicationDirPath() ).toString();
+	const QString statesPath = QtYabause::volatileSettings()->value( "General/SaveStates", getDataDirPath() ).toString();
 	QRegExp rx( QString( mask ).replace( '*', "(\\d+)") );
 	QDir d( statesPath );
 	foreach ( const QFileInfo& fi, d.entryInfoList( QStringList( mask ), QDir::Files | QDir::Readable, QDir::Name | QDir::IgnoreCase ) )
@@ -253,6 +285,16 @@ void UIYabause::on_aFileSettings_triggered()
 		VolatileSettings* vs = QtYabause::volatileSettings();
 		aEmulationFrameSkipLimiter->setChecked( vs->value( "General/EnableFrameSkipLimiter" ).toBool() );
 		aViewFPS->setChecked( vs->value( "General/ShowFPS" ).toBool() );
+
+		if ( vs->value( "View/Menubar" ).toInt() == 2 )
+			menubar->hide();
+		else
+			menubar->show();
+
+		if ( vs->value( "View/Toolbar" ).toInt() == 2 )
+			toolBar->hide();
+		else
+			toolBar->show();
 		
 		if ( mYabauseThread->pauseEmulation( true, true ) )
 			refreshStatesActions();
@@ -308,7 +350,7 @@ void UIYabause::on_mFileSaveState_triggered( QAction* a )
 	if ( a == aFileSaveStateAs )
 		return;
 	YabauseLocker locker( mYabauseThread );
-	if ( YabSaveStateSlot( QtYabause::volatileSettings()->value( "General/SaveStates", QApplication::applicationDirPath() ).toString().toAscii().constData(), a->data().toInt() ) != 0 )
+	if ( YabSaveStateSlot( QtYabause::volatileSettings()->value( "General/SaveStates", getDataDirPath() ).toString().toAscii().constData(), a->data().toInt() ) != 0 )
 		CommonDialogs::information( QtYabause::translate( "Couldn't save state file" ) );
 	else
 		refreshStatesActions();
@@ -319,14 +361,14 @@ void UIYabause::on_mFileLoadState_triggered( QAction* a )
 	if ( a == aFileLoadStateAs )
 		return;
 	YabauseLocker locker( mYabauseThread );
-	if ( YabLoadStateSlot( QtYabause::volatileSettings()->value( "General/SaveStates", QApplication::applicationDirPath() ).toString().toAscii().constData(), a->data().toInt() ) != 0 )
+	if ( YabLoadStateSlot( QtYabause::volatileSettings()->value( "General/SaveStates", getDataDirPath() ).toString().toAscii().constData(), a->data().toInt() ) != 0 )
 		CommonDialogs::information( QtYabause::translate( "Couldn't load state file" ) );
 }
 
 void UIYabause::on_aFileSaveStateAs_triggered()
 {
 	YabauseLocker locker( mYabauseThread );
-	const QString fn = CommonDialogs::getSaveFileName( QtYabause::volatileSettings()->value( "General/SaveStates", QApplication::applicationDirPath() ).toString(), QtYabause::translate( "Choose a file to save your state" ), QtYabause::translate( "Yabause Save State (*.yss)" ) );
+	const QString fn = CommonDialogs::getSaveFileName( QtYabause::volatileSettings()->value( "General/SaveStates", getDataDirPath() ).toString(), QtYabause::translate( "Choose a file to save your state" ), QtYabause::translate( "Yabause Save State (*.yss)" ) );
 	if ( fn.isNull() )
 		return;
 	if ( YabSaveState( fn.toAscii().constData() ) != 0 )
@@ -336,7 +378,7 @@ void UIYabause::on_aFileSaveStateAs_triggered()
 void UIYabause::on_aFileLoadStateAs_triggered()
 {
 	YabauseLocker locker( mYabauseThread );
-	const QString fn = CommonDialogs::getOpenFileName( QtYabause::volatileSettings()->value( "General/SaveStates", QApplication::applicationDirPath() ).toString(), QtYabause::translate( "Select a file to load your state" ), QtYabause::translate( "Yabause Save State (*.yss)" ) );
+	const QString fn = CommonDialogs::getOpenFileName( QtYabause::volatileSettings()->value( "General/SaveStates", getDataDirPath() ).toString(), QtYabause::translate( "Select a file to load your state" ), QtYabause::translate( "Yabause Save State (*.yss)" ) );
 	if ( fn.isNull() )
 		return;
 	if ( YabLoadState( fn.toAscii().constData() ) != 0 )
@@ -411,8 +453,21 @@ void UIYabause::on_aToolsCheatsList_triggered()
 	UICheats( this ).exec();
 }
 
+void UIYabause::on_aToolsCheatSearch_triggered()
+{
+   YabauseLocker locker( mYabauseThread );
+   UICheatSearch cs(this, searchResults, numSearchResults, searchType);
+      
+   cs.exec();
+
+   searchResults = cs.getSearchVariables(&numSearchResults, &searchType);
+}
+
 void UIYabause::on_aToolsTransfer_triggered()
-{}
+{
+	YabauseLocker locker( mYabauseThread );
+	UIMemoryTransfer( mYabauseThread, this ).exec();
+}
 
 void UIYabause::on_aViewFPS_triggered( bool toggled )
 {
@@ -443,6 +498,82 @@ void UIYabause::on_aViewFullscreen_triggered( bool b )
 	//ToggleFullScreen();
 }
 
+void UIYabause::breakpointHandlerMSH2()
+{
+	YabauseLocker locker( mYabauseThread );
+	CommonDialogs::information( QtYabause::translate( "Breakpoint Reached" ) );
+	UIDebugSH2( true, mYabauseThread, this ).exec();
+}
+
+void UIYabause::breakpointHandlerSSH2()
+{
+	YabauseLocker locker( mYabauseThread );
+	CommonDialogs::information( QtYabause::translate( "Breakpoint Reached" ) );
+	UIDebugSH2( false, mYabauseThread, this ).exec();
+}
+
+void UIYabause::breakpointHandlerM68K()
+{
+	YabauseLocker locker( mYabauseThread );
+	CommonDialogs::information( QtYabause::translate( "Breakpoint Reached" ) );
+	UIDebugM68K( mYabauseThread, this ).exec();
+}
+
+void UIYabause::breakpointHandlerSCUDSP()
+{
+	YabauseLocker locker( mYabauseThread );
+	CommonDialogs::information( QtYabause::translate( "Breakpoint Reached" ) );
+	UIDebugSCUDSP( mYabauseThread, this ).exec();
+}
+
+void UIYabause::on_aViewDebugMSH2_triggered()
+{
+	YabauseLocker locker( mYabauseThread );
+	UIDebugSH2( true, mYabauseThread, this ).exec();
+}
+
+void UIYabause::on_aViewDebugSSH2_triggered()
+{
+	YabauseLocker locker( mYabauseThread );
+	UIDebugSH2( false, mYabauseThread, this ).exec();
+}
+
+void UIYabause::on_aViewDebugVDP1_triggered()
+{
+	YabauseLocker locker( mYabauseThread );
+	UIDebugVDP1( this ).exec();
+}
+
+void UIYabause::on_aViewDebugVDP2_triggered()
+{
+	YabauseLocker locker( mYabauseThread );
+	UIDebugVDP2( this ).exec();
+}
+
+void UIYabause::on_aViewDebugM68K_triggered()
+{
+	YabauseLocker locker( mYabauseThread );
+	UIDebugM68K( mYabauseThread, this ).exec();
+}
+
+void UIYabause::on_aViewDebugSCUDSP_triggered()
+{
+	YabauseLocker locker( mYabauseThread );
+	UIDebugSCUDSP( mYabauseThread, this ).exec();
+}
+
+void UIYabause::on_aViewDebugSCSP_triggered()
+{
+	YabauseLocker locker( mYabauseThread );
+	UIDebugSCSP( this ).exec();
+}
+
+void UIYabause::on_aViewDebugMemoryEditor_triggered()
+{
+	YabauseLocker locker( mYabauseThread );
+	//UIMemoryEditor( this ).exec();
+}
+
 void UIYabause::on_aHelpEmuCompatibility_triggered()
 { QDesktopServices::openUrl( QUrl( aHelpEmuCompatibility->statusTip() ) ); }
 
@@ -485,9 +616,9 @@ void UIYabause::on_aVideoDriver_triggered()
 void UIYabause::on_cbSound_toggled( bool toggled )
 {
 	if ( toggled )
-		ScspUnMuteAudio();
+		ScspUnMuteAudio(SCSP_MUTE_USER);
 	else
-		ScspMuteAudio();
+		ScspMuteAudio(SCSP_MUTE_USER);
 	cbSound->setIcon( QIcon( toggled ? ":/actions/sound.png" : ":/actions/mute.png" ) );
 }
 
