@@ -70,6 +70,9 @@ protected:
 	QDockWidget* mLogDock;
 	QTextEdit* teLog;
 	bool mInit;
+   result_struct *searchResults;
+   u32 numSearchResults;
+   int searchType;
 
 	virtual void showEvent( QShowEvent* event );
 	virtual void closeEvent( QCloseEvent* event );
@@ -81,6 +84,10 @@ public slots:
 	void pause( bool paused );
 	void reset();
 
+	void breakpointHandlerMSH2();
+	void breakpointHandlerSSH2();
+	void breakpointHandlerM68K();
+	void breakpointHandlerSCUDSP();
 protected slots:
 	void errorReceived( const QString& error, bool internal = true );
 	void sizeRequested( const QSize& size );
@@ -104,6 +111,7 @@ protected slots:
 	// tools
 	void on_aToolsBackupManager_triggered();
 	void on_aToolsCheatsList_triggered();
+   void on_aToolsCheatSearch_triggered();
 	void on_aToolsTransfer_triggered();
 	// view menu
 	void on_aViewFPS_triggered( bool toggled );
@@ -114,6 +122,15 @@ protected slots:
 	void on_aViewLayerNBG3_triggered();
 	void on_aViewLayerRBG0_triggered();
 	void on_aViewFullscreen_triggered( bool b );
+	// debug menu
+	void on_aViewDebugMSH2_triggered();
+	void on_aViewDebugSSH2_triggered();
+	void on_aViewDebugVDP1_triggered();
+	void on_aViewDebugVDP2_triggered();
+	void on_aViewDebugM68K_triggered();
+	void on_aViewDebugSCSP_triggered();
+	void on_aViewDebugSCUDSP_triggered();
+	void on_aViewDebugMemoryEditor_triggered();
 	// help menu
 	void on_aHelpEmuCompatibility_triggered();
 	void on_aHelpAbout_triggered();
