@@ -25,6 +25,10 @@
 #include "memory.h"
 #include "yabause.h"
 
+#if defined(SH2_DYNAREC)
+#include "sh2_dynarec/sh2_dynarec.h"
+#endif
+
 SH2_struct *MSH2=NULL;
 SH2_struct *SSH2=NULL;
 SH2_struct *CurrentSH2;
@@ -72,13 +76,11 @@ int SH2Init(int coreid)
       }
    }
 
-   if (SH2Core) {
-      if (SH2Core->Init() != 0) {
-         free(MSH2);
-         free(SSH2);
-         MSH2 = SSH2 = NULL;
-         return -1;
-      }
+   if ((SH2Core == NULL) || (SH2Core->Init() != 0)) {
+      free(MSH2);
+      free(SSH2);
+      MSH2 = SSH2 = NULL;
+      return -1;
    }
 
    return 0;
@@ -186,15 +188,18 @@ void SH2NMI(SH2_struct *context)
 
 void SH2Step(SH2_struct *context)
 {
-   u32 tmp = SH2Core->GetPC(context);
+   if (SH2Core)
+   {
+      u32 tmp = SH2Core->GetPC(context);
 
-   // Execute 1 instruction
-   SH2Exec(context, context->cycles+1);
-
-   // Sometimes it doesn't always execute one instruction,
-   // let's make sure it did
-   if (tmp == SH2Core->GetPC(context))
+      // Execute 1 instruction
       SH2Exec(context, context->cycles+1);
+
+      // Sometimes it doesn't always execute one instruction,
+      // let's make sure it did
+      if (tmp == SH2Core->GetPC(context))
+         SH2Exec(context, context->cycles+1);
+   }
 }
 
 //////////////////////////////////////////////////////////////////////////////
