@@ -241,7 +241,7 @@ u16 FASTCALL Vdp1ReadWord(u32 addr) {
       case 0x14:
          return Vdp1Regs->COPR;
       case 0x16:
-         return Vdp1Regs->MODR;
+         return 0x1000 | ((Vdp1Regs->PTMR & 2) << 7) | ((Vdp1Regs->FBCR & 0x1E) << 3) | (Vdp1Regs->TVMR & 0xF);
       default:
          LOG("trying to read a Vdp1 write-only register\n");
    }
@@ -273,6 +273,12 @@ void FASTCALL Vdp1WriteWord(u32 addr, u16 val) {
          break;
       case 0x2:
          Vdp1Regs->FBCR = val;
+         if ((Vdp1Regs->FBCR & 3) == 3)
+         {
+            Vdp1External.manualchange = 1;
+         }
+         else if ((Vdp1Regs->FBCR & 3) == 2)
+            Vdp1External.manualerase = 1;
          break;
       case 0x4:
          Vdp1Regs->PTMR = val;
@@ -341,18 +347,22 @@ void Vdp1Draw(void) {
                VIDCore->Vdp1ScaledSpriteDraw();
                break;
             case 2: // distorted sprite draw
+            case 3: /* this one should be invalid, but some games
+                    (Hardcore 4x4 for instance) use it instead of 2 */
                VIDCore->Vdp1DistortedSpriteDraw();
                break;
             case 4: // polygon draw
                VIDCore->Vdp1PolygonDraw();
                break;
             case 5: // polyline draw
+            case 7: // undocumented mirror
                VIDCore->Vdp1PolylineDraw();
                break;
             case 6: // line draw
                VIDCore->Vdp1LineDraw();
                break;
             case 8: // user clipping coordinates
+            case 11: // undocumented mirror
                VIDCore->Vdp1UserClipping();
                break;
             case 9: // system clipping coordinates
@@ -363,6 +373,7 @@ void Vdp1Draw(void) {
                break;
             default: // Abort
                VDP1LOG("vdp1\t: Bad command: %x\n",  command);
+               Vdp1Regs->EDSR |= 2;
                VIDCore->Vdp1DrawEnd();
                Vdp1Regs->LOPR = Vdp1Regs->addr >> 3;
                Vdp1Regs->COPR = Vdp1Regs->addr >> 3;
@@ -434,11 +445,15 @@ void Vdp1NoDraw(void) {
             case 0: // normal sprite draw
             case 1: // scaled sprite draw
             case 2: // distorted sprite draw
+            case 3: /* this one should be invalid, but some games
+                    (Hardcore 4x4 for instance) use it instead of 2 */
             case 4: // polygon draw
             case 5: // polyline draw
             case 6: // line draw
+            case 7: // undocumented polyline draw mirror
                break;
             case 8: // user clipping coordinates
+            case 11: // undocumented mirror
                VIDCore->Vdp1UserClipping();
                break;
             case 9: // system clipping coordinates
@@ -449,6 +464,7 @@ void Vdp1NoDraw(void) {
                break;
             default: // Abort
                VDP1LOG("vdp1\t: Bad command: %x\n",  command);
+               Vdp1Regs->EDSR |= 2;
                VIDCore->Vdp1DrawEnd();
                Vdp1Regs->LOPR = Vdp1Regs->addr >> 3;
                Vdp1Regs->COPR = Vdp1Regs->addr >> 3;
@@ -620,18 +636,24 @@ char *Vdp1DebugGetCommandNumberName(u32 number)
             return "Scaled Sprite";
          case 2:
             return "Distorted Sprite";
+         case 3:
+            return "Distorted Sprite *";
          case 4:
             return "Polygon";
          case 5:
             return "Polyline";
          case 6:
             return "Line";
+         case 7:
+            return "Polyline *";
          case 8:
             return "User Clipping Coordinates";
          case 9:
             return "System Clipping Coordinates";
          case 10:
             return "Local Coordinates";
+         case 11:
+            return "User Clipping Coordinates *";
          default:
              return "Bad command";
       }
@@ -729,6 +751,11 @@ void Vdp1DebugCommand(u32 number, char *outstring)
          AddString(outstring, "x1 = %d, y1 = %d, x2 = %d, y2 = %d\r\n", cmd.CMDXA, cmd.CMDYA, cmd.CMDXB, cmd.CMDYB);
          AddString(outstring, "x3 = %d, y3 = %d, x4 = %d, y4 = %d\r\n", cmd.CMDXC, cmd.CMDYC, cmd.CMDXD, cmd.CMDYD);
          break;
+      case 3:
+         AddString(outstring, "Distorted Sprite *\r\n");
+         AddString(outstring, "x1 = %d, y1 = %d, x2 = %d, y2 = %d\r\n", cmd.CMDXA, cmd.CMDYA, cmd.CMDXB, cmd.CMDYB);
+         AddString(outstring, "x3 = %d, y3 = %d, x4 = %d, y4 = %d\r\n", cmd.CMDXC, cmd.CMDYC, cmd.CMDXD, cmd.CMDYD);
+         break;
       case 4:
          AddString(outstring, "Polygon\r\n");
          AddString(outstring, "x1 = %d, y1 = %d, x2 = %d, y2 = %d\r\n", cmd.CMDXA, cmd.CMDYA, cmd.CMDXB, cmd.CMDYB);
@@ -743,6 +770,11 @@ void Vdp1DebugCommand(u32 number, char *outstring)
          AddString(outstring, "Line\r\n");
          AddString(outstring, "x1 = %d, y1 = %d, x2 = %d, y2 = %d\r\n", cmd.CMDXA, cmd.CMDYA, cmd.CMDXB, cmd.CMDYB);
          break;
+      case 7:
+         AddString(outstring, "Polyline *\r\n");
+         AddString(outstring, "x1 = %d, y1 = %d, x2 = %d, y2 = %d\r\n", cmd.CMDXA, cmd.CMDYA, cmd.CMDXB, cmd.CMDYB);
+         AddString(outstring, "x3 = %d, y3 = %d, x4 = %d, y4 = %d\r\n", cmd.CMDXC, cmd.CMDYC, cmd.CMDXD, cmd.CMDYD);
+         break;
       case 8:
          AddString(outstring, "User Clipping\r\n");
          AddString(outstring, "x1 = %d, y1 = %d, x2 = %d, y2 = %d\r\n", cmd.CMDXA, cmd.CMDYA, cmd.CMDXC, cmd.CMDYC);
@@ -1006,6 +1038,7 @@ u32 *Vdp1DebugTexture(u32 number, int *w, int *h)
       case 0: // Normal Sprite
       case 1: // Scaled Sprite
       case 2: // Distorted Sprite
+      case 3: // Distorted Sprite *
          w[0] = (cmd.CMDSIZE & 0x3F00) >> 5;
          h[0] = cmd.CMDSIZE & 0xFF;
 
@@ -1023,6 +1056,7 @@ u32 *Vdp1DebugTexture(u32 number, int *w, int *h)
       case 4: // Polygon
       case 5: // Polyline
       case 6: // Line
+      case 7: // Polyline *
          // Do 1x1 pixel
          w[0] = 1;
          h[0] = 1;
@@ -1038,6 +1072,7 @@ u32 *Vdp1DebugTexture(u32 number, int *w, int *h)
       case 8: // User Clipping
       case 9: // System Clipping
       case 10: // Local Coordinates
+      case 11: // User Clipping *
          return NULL;
       default: // Invalid command
          return NULL;
