@@ -26,9 +26,7 @@
 #include "vdp1.h"
 #include "yabause.h"
 #include "movie.h"
-
-char OSDMessage[32] = "";	//adelikat: For showing on screen messages such as savestate loaded/saved
-int OSDMessageTimer = 120;
+#include "osdcore.h"
 
 u8 * Vdp2Ram;
 u8 * Vdp2ColorRam;
@@ -36,40 +34,12 @@ Vdp2 * Vdp2Regs;
 Vdp2Internal_struct Vdp2Internal;
 Vdp2External_struct Vdp2External;
 
+static Vdp2 Vdp2Lines[270];
+
 static int autoframeskipenab=0;
-static int framestoskip=0;
-static int framesskipped=0;
 static int throttlespeed=0;
-static int skipnextframe=0;
 u64 lastticks=0;
-static u64 curticks=0;
-static u64 diffticks=0;
-static u32 framecount=0;
-static u64 onesecondticks=0;
 static int fps;
-static int fpsframecount=0;
-static u64 fpsticks;
-static int fpstoggle=0;
-
-//////////////////////////////////////////////////////////////////////////////
-int GetOSDToggle(void)
-{
-	return fpstoggle;
-}
-
-//////////////////////////////////////////////////////////////////////////////
-void SetOSDToggle(int toggle)
-{
-	fpstoggle = toggle;
-}
-
-//////////////////////////////////////////////////////////////////////////////
-//adelikat: This function will handle the OSDMessage variable properly, it should be used by other functions for displaying information to the user
-void DisplayMessage(const char* str)
-{
-	strcpy(OSDMessage, str);
-	OSDMessageTimer = 120;
-}
 
 //////////////////////////////////////////////////////////////////////////////
 
@@ -278,6 +248,11 @@ void Vdp2Reset(void) {
 //////////////////////////////////////////////////////////////////////////////
 
 void Vdp2VBlankIN(void) {
+   /* I'm not 100% sure about this, but it seems that when using manual change
+   we should swap framebuffers in the "next field" and thus, clear the CEF...
+   now we're lying a little here as we're not swapping the framebuffers. */
+   if (Vdp1External.manualchange) Vdp1Regs->EDSR >>= 1;
+
    Vdp2Regs->TVSTAT |= 0x0008;
    ScuSendVBlankIN();
 
@@ -299,38 +274,37 @@ void Vdp2HBlankIN(void) {
 
 void Vdp2HBlankOUT(void) {
    Vdp2Regs->TVSTAT &= ~0x0004;
+
+   if (yabsys.LineCount < 270)
+      memcpy(Vdp2Lines + yabsys.LineCount, Vdp2Regs, sizeof(Vdp2));
+}
+
+//////////////////////////////////////////////////////////////////////////////
+
+Vdp2 * Vdp2RestoreRegs(int line) {
+   return line > 270 ? NULL : Vdp2Lines + line;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
 static void FPSDisplay(void)
 {
-   if (fpstoggle)
+   static int fpsframecount = 0;
+   static u64 fpsticks;
+
+   OSDPushMessage(OSDMSG_FPS, 1, "%02d/%02d FPS", fps, yabsys.IsPal ? 50 : 60);
+   OSDPushMessage(OSDMSG_DEBUG, 1, "%d %d %s %s", framecounter, lagframecounter, MovieStatus, InputDisplayString);
+   fpsframecount++;
+   if(YabauseGetTicks() >= fpsticks + yabsys.tickfreq)
    {
-      if (!OSDMessageTimer)
-		OSDMessage[0] = 0;
-	  VIDCore->OnScreenDebugMessage("%02d/%02d FPS %d %d %s %s %s", fps, yabsys.IsPal ? 50 : 60, framecounter, lagframecounter, MovieStatus, InputDisplayString, OSDMessage);
-	  if (OSDMessageTimer > 0)
-		  OSDMessageTimer--;
-      fpsframecount++;
-      if(YabauseGetTicks() >= fpsticks + yabsys.tickfreq)
-      {
-         fps = fpsframecount;
-         fpsframecount = 0;
-         fpsticks = YabauseGetTicks();
-      }
+      fps = fpsframecount;
+      fpsframecount = 0;
+      fpsticks = YabauseGetTicks();
    }
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void ToggleFPS(void)
-{
-   fpstoggle ^= 1;
-}
-
-//////////////////////////////////////////////////////////////////////////////
-
 void SpeedThrottleEnable(void) {
    throttlespeed = 1;
 }
@@ -344,22 +318,44 @@ void SpeedThrottleDisable(void) {
 //////////////////////////////////////////////////////////////////////////////
 
 void Vdp2VBlankOUT(void) {
+   static int framestoskip = 0;
+   static int framesskipped = 0;
+   static int skipnextframe = 0;
+   static u64 curticks = 0;
+   static u64 diffticks = 0;
+   static u32 framecount = 0;
+   static u64 onesecondticks = 0;
+   static VideoInterface_struct * saved = NULL;
+
    Vdp2Regs->TVSTAT = (Vdp2Regs->TVSTAT & ~0x0008) | 0x0002;
 
+   if (skipnextframe && (! saved))
+   {
+      saved = VIDCore;
+      VIDCore = &VIDDummy;
+   }
+   else if (saved && (! skipnextframe))
+   {
+      VIDCore = saved;
+      saved = NULL;
+   }
+
+   VIDCore->Vdp2DrawStart();
+
+   if (Vdp2Regs->TVMD & 0x8000) {
+      VIDCore->Vdp2DrawScreens();
+      Vdp1Draw();
+   }
+   else
+      Vdp1NoDraw();
+
+   FPSDisplay();
+   VIDCore->Vdp2DrawEnd();
+   /* this should be done after a frame change or a plot trigger */
+   Vdp1Regs->COPR = 0;
+
    if (!skipnextframe)
    {
-      VIDCore->Vdp2DrawStart();
-
-      if (Vdp2Regs->TVMD & 0x8000) {
-         VIDCore->Vdp2DrawScreens();
-         Vdp1Draw();
-      }
-      else
-         Vdp1NoDraw();
-
-      FPSDisplay();
-      VIDCore->Vdp2DrawEnd();
-
       framesskipped = 0;
 
       if (framestoskip > 0)
@@ -373,7 +369,6 @@ void Vdp2VBlankOUT(void) {
          skipnextframe = 0;
       else
          skipnextframe = 1;
-      Vdp1NoDraw();
 
       framesskipped++;
    }
@@ -952,308 +947,10 @@ void FASTCALL Vdp2WriteWord(u32 addr, u16 val) {
 //////////////////////////////////////////////////////////////////////////////
 
 void FASTCALL Vdp2WriteLong(u32 addr, u32 val) {
-   addr &= 0x1FF;
-
-   switch (addr)
-   {
-      case 0x000:
-         Vdp2Regs->TVMD = val >> 16;
-         Vdp2Regs->EXTEN = val & 0xFFFF;
-         VIDCore->Vdp2SetResolution(Vdp2Regs->TVMD);
-         yabsys.VBlankLineCount = 224+(Vdp2Regs->TVMD & 0x30);
-         return;
-      case 0x004:
-         Vdp2Regs->VRSIZE = val & 0xFFFF;
-         return;
-      case 0x008:
-         // read-only
-         return;
-      case 0x00C:
-         Vdp2Regs->RAMCTL = val & 0xFFFF;
-         return;
-      case 0x010:
-         Vdp2Regs->CYCA0L = val >> 16;
-         Vdp2Regs->CYCA0U = val & 0xFFFF;
-         return;
-      case 0x014:
-         Vdp2Regs->CYCA1L = val >> 16;
-         Vdp2Regs->CYCA1U = val & 0xFFFF;
-         return;
-      case 0x018:
-         Vdp2Regs->CYCB0L = val >> 16;
-         Vdp2Regs->CYCB0U = val & 0xFFFF;
-         return;
-      case 0x01C:
-         Vdp2Regs->CYCB1L = val >> 16;
-         Vdp2Regs->CYCB1U = val & 0xFFFF;
-         return;
-      case 0x020:
-         Vdp2Regs->BGON = val >> 16;
-         Vdp2Regs->MZCTL = val & 0xFFFF;
-         return;
-      case 0x024:
-         Vdp2Regs->SFSEL = val >> 16;
-         Vdp2Regs->SFCODE = val & 0xFFFF;
-         return;
-      case 0x028:
-         Vdp2Regs->CHCTLA = val >> 16;
-         Vdp2Regs->CHCTLB = val & 0xFFFF;
-         return;
-      case 0x02C:
-         Vdp2Regs->BMPNA = val >> 16;
-         Vdp2Regs->BMPNB = val & 0xFFFF;
-         return;
-      case 0x030:
-         Vdp2Regs->PNCN0 = val >> 16;
-         Vdp2Regs->PNCN1 = val & 0xFFFF;
-         return;
-      case 0x034:
-         Vdp2Regs->PNCN2 = val >> 16;
-         Vdp2Regs->PNCN3 = val & 0xFFFF;
-         return;
-      case 0x038:
-         Vdp2Regs->PNCR = val >> 16;
-         Vdp2Regs->PLSZ = val & 0xFFFF;
-         return;
-      case 0x03C:
-         Vdp2Regs->MPOFN = val >> 16;
-         Vdp2Regs->MPOFR = val & 0xFFFF;
-         return;
-      case 0x040:
-         Vdp2Regs->MPABN0 = val >> 16;
-         Vdp2Regs->MPCDN0 = val & 0xFFFF;
-         return;
-      case 0x044:
-         Vdp2Regs->MPABN1 = val >> 16;
-         Vdp2Regs->MPCDN1 = val & 0xFFFF;
-         return;
-      case 0x048:
-         Vdp2Regs->MPABN2 = val >> 16;
-         Vdp2Regs->MPCDN2 = val & 0xFFFF;
-         return;
-      case 0x04C:
-         Vdp2Regs->MPABN3 = val >> 16;
-         Vdp2Regs->MPCDN3 = val & 0xFFFF;
-         return;
-      case 0x050:
-         Vdp2Regs->MPABRA = val >> 16;
-         Vdp2Regs->MPCDRA = val & 0xFFFF;
-         return;
-      case 0x054:
-         Vdp2Regs->MPEFRA = val >> 16;
-         Vdp2Regs->MPGHRA = val & 0xFFFF;
-         return;
-      case 0x058:
-         Vdp2Regs->MPIJRA = val >> 16;
-         Vdp2Regs->MPKLRA = val & 0xFFFF;
-         return;
-      case 0x05C:
-         Vdp2Regs->MPMNRA = val >> 16;
-         Vdp2Regs->MPOPRA = val & 0xFFFF;
-         return;
-      case 0x060:
-         Vdp2Regs->MPABRB = val >> 16;
-         Vdp2Regs->MPCDRB = val & 0xFFFF;
-         return;
-      case 0x064:
-         Vdp2Regs->MPEFRB = val >> 16;
-         Vdp2Regs->MPGHRB = val & 0xFFFF;
-         return;
-      case 0x068:
-         Vdp2Regs->MPIJRB = val >> 16;
-         Vdp2Regs->MPKLRB = val & 0xFFFF;
-         return;
-      case 0x06C:
-         Vdp2Regs->MPMNRB = val >> 16;
-         Vdp2Regs->MPOPRB = val & 0xFFFF;
-         return;
-      case 0x070:
-         Vdp2Regs->SCXIN0 = val >> 16;
-         // SCXDN0 here
-         return;
-      case 0x074:
-         Vdp2Regs->SCYIN0 = val >> 16;
-         // SCYDN0 here
-         return;
-      case 0x078:
-         Vdp2Regs->ZMXN0.all = val;
-         return;
-      case 0x07C:
-         Vdp2Regs->ZMYN0.all = val;
-         return;
-      case 0x080:
-         Vdp2Regs->SCXIN1 = val >> 16;
-         // SCXDN1 here
-         return;
-      case 0x084:
-         Vdp2Regs->SCYIN1 = val >> 16;
-         // SCYDN1 here
-         return;
-      case 0x088:
-         Vdp2Regs->ZMXN1.all = val;
-         return;
-      case 0x08C:
-         Vdp2Regs->ZMYN1.all = val;
-         return;
-      case 0x090:
-         Vdp2Regs->SCXN2 = val >> 16;
-         Vdp2Regs->SCYN2 = val & 0xFFFF;
-         return;
-      case 0x094:
-         Vdp2Regs->SCXN3 = val >> 16;
-         Vdp2Regs->SCYN3 = val & 0xFFFF;
-         return;
-      case 0x09C:
-         Vdp2Regs->VCSTA.all = val;
-         return;
-      case 0x0A0:
-         Vdp2Regs->LSTA0.all = val;
-         return;
-      case 0x0A4:
-         Vdp2Regs->LSTA1.all = val;
-         return;
-      case 0x0AC:
-         Vdp2Regs->BKTAU = val >> 16;
-         Vdp2Regs->BKTAL = val & 0xFFFF;
-         return;
-      case 0x0D0:
-         Vdp2Regs->WCTLA = val >> 16;
-         Vdp2Regs->WCTLB = val & 0xFFFF;
-         return;
-      case 0x0D8:
-         Vdp2Regs->LWTA0.all = val;
-         return;
-      case 0x0DC:
-         Vdp2Regs->LWTA1.all = val;
-         return;
-      case 0x0E0:
-         Vdp2Regs->SPCTL = val >> 16;
-         Vdp2Regs->SDCTL = val & 0xFFFF;
-         return;
-      case 0x0E4:
-         Vdp2Regs->CRAOFA = val >> 16;
-         Vdp2Regs->CRAOFB = val & 0xFFFF;
-         return;
-      case 0x0E8:
-         Vdp2Regs->LNCLEN = val >> 16;
-         Vdp2Regs->SFPRMD = val & 0xFFFF;
-         return;
-      case 0x0EC:
-         Vdp2Regs->CCCTL = val >> 16;
-         Vdp2Regs->SFCCMD = val & 0xFFFF;
-         return;
-      case 0x0F0:
-         Vdp2Regs->PRISA = val >> 16;
-         Vdp2Regs->PRISB = val & 0xFFFF;
-         return;
-      case 0x0F4:
-         Vdp2Regs->PRISC = val >> 16;
-         Vdp2Regs->PRISD = val & 0xFFFF;
-         return;
-      case 0x0F8:
-         Vdp2Regs->PRINA = val >> 16;
-         Vdp2Regs->PRINB = val & 0xFFFF;
-         VIDCore->Vdp2SetPriorityNBG0(Vdp2Regs->PRINA & 0x7);
-         VIDCore->Vdp2SetPriorityNBG1((Vdp2Regs->PRINA >> 8) & 0x7);
-         VIDCore->Vdp2SetPriorityNBG2(Vdp2Regs->PRINB & 0x7);
-         VIDCore->Vdp2SetPriorityNBG3((Vdp2Regs->PRINB >> 8) & 0x7);
-         return;
-      case 0x100:
-         Vdp2Regs->CCRSA = val >> 16;
-         Vdp2Regs->CCRSB = val & 0xFFFF;
-         return;
-      case 0x104:
-         Vdp2Regs->CCRSC = val >> 16;
-         Vdp2Regs->CCRSD = val & 0xFFFF;
-         return;
-      case 0x108:
-         Vdp2Regs->CCRNA = val >> 16;
-         Vdp2Regs->CCRNB = val & 0xFFFF;
-         return;
-      case 0x10C:
-         Vdp2Regs->CCRR = val >> 16;
-         Vdp2Regs->CCRLB = val & 0xFFFF;
-         return;
-      case 0x110:
-         Vdp2Regs->CLOFEN = val >> 16;
-         Vdp2Regs->CLOFSL = val & 0xFFFF;
-         return;
-      case 0x114:
-         Vdp2Regs->COAR = val >> 16;
-         Vdp2Regs->COAG = val & 0xFFFF;
-         return;
-      case 0x118:
-         Vdp2Regs->COAB = val >> 16;
-         Vdp2Regs->COBR = val & 0xFFFF;
-         return;
-      case 0x11C:
-         Vdp2Regs->COBG = val >> 16;
-         Vdp2Regs->COBB = val & 0xFFFF;
-         return;
-      case 0x120:
-      case 0x124:
-      case 0x128:
-      case 0x12C:
-      case 0x130:
-      case 0x134:
-      case 0x138:
-      case 0x13C:
-      case 0x140:
-      case 0x144:
-      case 0x148:
-      case 0x14C:
-      case 0x150:
-      case 0x154:
-      case 0x158:
-      case 0x15C:
-      case 0x160:
-      case 0x164:
-      case 0x168:
-      case 0x16C:
-      case 0x170:
-      case 0x174:
-      case 0x178:
-      case 0x17C:
-      case 0x180:
-      case 0x184:
-      case 0x188:
-      case 0x18C:
-      case 0x190:
-      case 0x194:
-      case 0x198:
-      case 0x19C:
-      case 0x1A0:
-      case 0x1A4:
-      case 0x1A8:
-      case 0x1AC:
-      case 0x1B0:
-      case 0x1B4:
-      case 0x1B8:
-      case 0x1BC:
-      case 0x1C0:
-      case 0x1C4:
-      case 0x1C8:
-      case 0x1CC:
-      case 0x1D0:
-      case 0x1D4:
-      case 0x1D8:
-      case 0x1DC:
-      case 0x1E0:
-      case 0x1E4:
-      case 0x1E8:
-      case 0x1EC:
-      case 0x1F0:
-      case 0x1F4:
-      case 0x1F8:
-      case 0x1FC:
-         // Reserved
-         return;
-      default:
-      {
-         LOG("Unhandled VDP2 long write: %08X\n", addr);
-         break;
-      }
-   }
+   
+   Vdp2WriteWord(addr,val>>16);
+   Vdp2WriteWord(addr+2,val&0xFFFF);
+   return;
 }
 
 //////////////////////////////////////////////////////////////////////////////
