@@ -18,11 +18,11 @@
 */
 
 #include "vdp2.h"
+#include "ygl.h"
 #include "vdp2debug.h"
 #include "vidshared.h"
 #include "vidsoft.h"
-
-void FASTCALL Vdp2DrawScroll(vdp2draw_struct *info, u32 *textdata, int width, int height);
+#include "titan/titan.h"
 
 //////////////////////////////////////////////////////////////////////////////
 
@@ -136,49 +136,12 @@ static INLINE char *AddBitmapInfoString(char *outstring, int wh, int palnum, int
 
 static void CalcWindowCoordinates(int num, int *hstart, int *vstart, int *hend, int *vend)
 {
-   if (num == 0)
-   {
-      // Window 0
-      *hstart = Vdp2Regs->WPSX0;
-      *vstart = Vdp2Regs->WPSY0 & 0x1FF;
-      *hend = Vdp2Regs->WPEX0;
-      *vend = Vdp2Regs->WPEY0 & 0x1FF;
-   }
-   else
-   {
-      // Window 1
-      *hstart = Vdp2Regs->WPSX1;
-      *vstart = Vdp2Regs->WPSY1 & 0x1FF;
-      *hend = Vdp2Regs->WPEX1;
-      *vend = Vdp2Regs->WPEY1 & 0x1FF;
-   }
-
-   switch ((Vdp2Regs->TVMD >> 1) & 0x3)
-   {
-      case 0: // Normal
-         *hstart = (*hstart >> 1) & 0x1FF;
-         *hend = (*hend >> 1) & 0x1FF;
-         break;
-      case 1: // Hi-Res
-         *hstart = *hstart & 0x3FF;
-         *hend = *hend & 0x3FF;
-         break;
-      case 2: // Exclusive Normal
-         *hstart = *hstart & 0x1FF;
-         *hend = *hend & 0x1FF;
-         break;
-      case 3: // Exclusive Hi-Res
-         *hstart = (*hstart & 0x3FF) >> 1;
-         *hend = (*hend & 0x3FF) >> 1;
-         break;
-   }
-
-   if ((Vdp2Regs->TVMD & 0xC0) == 0xC0)
-   {
-      // Double-density interlace
-      *vstart >>= 1;
-      *vend >>= 1;
-   }
+   clipping_struct clip;
+   ReadWindowCoordinates(num, &clip);
+   *hstart = clip.xstart;
+   *vstart = clip.ystart;
+   *hend = clip.xend;
+   *vend = clip.yend;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -549,7 +512,7 @@ void Vdp2DebugStatsRBG0(char *outstring, int *isenabled)
          else
          {
             AddString(outstring, "Pattern Name data size = 1 word\r\n");
-            AddString(outstring, "Character Number Supplement bit = %d\r\n", (supplementdata >> 16));
+            AddString(outstring, "Character Number Supplement bit = %d\r\n", (supplementdata >> 14) & 0x1);
             AddString(outstring, "Special Priority bit = %d\r\n", (supplementdata >> 9) & 0x1);
             AddString(outstring, "Special Color Calculation bit = %d\r\n", (supplementdata >> 8) & 0x1);
             AddString(outstring, "Supplementary Palette number = %d\r\n", (supplementdata >> 5) & 0x7);
@@ -676,6 +639,8 @@ void Vdp2DebugStatsRBG0(char *outstring, int *isenabled)
 
       // Color Offset
       outstring = AddColorOffsetInfo(outstring, 0x0010);
+      
+      AddString(outstring, "Special Color Calculation %d\r\n",(Vdp2Regs->SFCCMD>>8)&0x03);
    }
    else
    {
@@ -750,7 +715,7 @@ void Vdp2DebugStatsNBG0(char *outstring, int *isenabled)
          else
          {
             AddString(outstring, "Pattern Name data size = 1 word\r\n");
-            AddString(outstring, "Character Number Supplement bit = %d\r\n", (supplementdata >> 16));
+            AddString(outstring, "Character Number Supplement bit = %d\r\n", (supplementdata >> 14) & 0x1);
             AddString(outstring, "Special Priority bit = %d\r\n", (supplementdata >> 9) & 0x1);
             AddString(outstring, "Special Color Calculation bit = %d\r\n", (supplementdata >> 8) & 0x1);
             AddString(outstring, "Supplementary Palette number = %d\r\n", (supplementdata >> 5) & 0x7);
@@ -951,6 +916,9 @@ void Vdp2DebugStatsNBG0(char *outstring, int *isenabled)
 
       // Color Offset
       outstring = AddColorOffsetInfo(outstring, 0x0001);
+      
+      AddString(outstring, "Special Color Calculation %d\r\n",(Vdp2Regs->SFCCMD>>0)&0x03);
+         
    }
    else
    {
@@ -1010,7 +978,7 @@ void Vdp2DebugStatsNBG1(char *outstring, int *isenabled)
          else
          {
             AddString(outstring, "Pattern Name data size = 1 word\r\n");
-            AddString(outstring, "Character Number Supplement bit = %d\r\n", (supplementdata >> 16));
+            AddString(outstring, "Character Number Supplement bit = %d\r\n", (supplementdata >> 14) & 0x1);
             AddString(outstring, "Special Priority bit = %d\r\n", (supplementdata >> 9) & 0x1);
             AddString(outstring, "Special Color Calculation bit = %d\r\n", (supplementdata >> 8) & 0x1);
             AddString(outstring, "Supplementary Palette number = %d\r\n", (supplementdata >> 5) & 0x7);
@@ -1162,6 +1130,8 @@ void Vdp2DebugStatsNBG1(char *outstring, int *isenabled)
 
       // Color Offset
       outstring = AddColorOffsetInfo(outstring, 0x0002);
+      
+      AddString(outstring, "Special Color Calculation %d\r\n",(Vdp2Regs->SFCCMD>>2)&0x03);
    }
    else
      // disabled
@@ -1208,7 +1178,7 @@ void Vdp2DebugStatsNBG2(char *outstring, int *isenabled)
       else
       {
          AddString(outstring, "Pattern Name data size = 1 word\r\n");
-         AddString(outstring, "Character Number Supplement bit = %d\r\n", (supplementdata >> 16));
+         AddString(outstring, "Character Number Supplement bit = %d\r\n", (supplementdata >> 14) & 0x1);
          AddString(outstring, "Special Priority bit = %d\r\n", (supplementdata >> 9) & 0x1);
          AddString(outstring, "Special Color Calculation bit = %d\r\n", (supplementdata >> 8) & 0x1);
          AddString(outstring, "Supplementary Palette number = %d\r\n", (supplementdata >> 5) & 0x7);
@@ -1296,6 +1266,8 @@ void Vdp2DebugStatsNBG2(char *outstring, int *isenabled)
 
       // Color Offset
       outstring = AddColorOffsetInfo(outstring, 0x0004);
+      
+      AddString(outstring, "Special Color Calculation %d\r\n",(Vdp2Regs->SFCCMD>>4)&0x03);
    }
    else
    {
@@ -1344,7 +1316,7 @@ void Vdp2DebugStatsNBG3(char *outstring, int *isenabled)
       else
       {
          AddString(outstring, "Pattern Name data size = 1 word\r\n");
-         AddString(outstring, "Character Number Supplement bit = %d\r\n", (supplementdata >> 16));
+         AddString(outstring, "Character Number Supplement bit = %d\r\n", (supplementdata >> 14) & 0x1);
          AddString(outstring, "Special Priority bit = %d\r\n", (supplementdata >> 9) & 0x1);
          AddString(outstring, "Special Color Calculation bit = %d\r\n", (supplementdata >> 8) & 0x1);
          AddString(outstring, "Supplementary Palette number = %d\r\n", (supplementdata >> 5) & 0x7);
@@ -1433,6 +1405,8 @@ void Vdp2DebugStatsNBG3(char *outstring, int *isenabled)
 
       // Color Offset
       outstring = AddColorOffsetInfo(outstring, 0x0008);
+      
+      AddString(outstring, "Special Color Calculation %d\r\n",(Vdp2Regs->SFCCMD>>6)&0x03);
    }
    else
    {
@@ -1678,258 +1652,19 @@ static void ClearTextureToColor(u32 *texture, u32 color, int w, int h)
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 *Vdp2DebugTexture(u32 screen, int tilenum, u32 transparentcolor, int *w, int *h)
+u32 *Vdp2DebugTexture(u32 screen, int * w, int * h)
 {
-   vdp2draw_struct info;
-   u32 *bitmap=NULL;
+   u32 * bitmap;
 
-   // If tilenum == -1, the entire screen is used
-   // For bitmap modes, NULL is returned if tilenum != -1
-   info.x = 0;
-   info.y = 0;
-   info.coordincx = 1.0;
-   info.coordincy = 1.0;
-   info.mosaicxmask = 1;
-   info.mosaicymask = 1;
-   info.islinescroll = 0;
-   info.wctl = 0;
-   info.islinewindow = 0;
-   info.PostPixelFetchCalc = &DoNothing;
-   info.priority = 1;
+   TitanInit();
+   VIDSoftVdp2DrawScreen(screen);
 
-   switch (screen)
-   {
-      case 0: //NBG0/RBG1
-      {
-         if (Vdp2Regs->BGON & 0x20)
-         {
-            // RBG1 mode
-            info.enable = Vdp2Regs->BGON & 0x20;
+   if ((bitmap = (u32 *)calloc(sizeof(u32), 704 * 512)) == NULL)
+      return NULL;
 
-            if((info.isbitmap = Vdp2Regs->CHCTLA & 0x2) != 0)
-            {
-               // Bitmap Mode
+   TitanGetResolution(w, h);
 
-               ReadBitmapSize(&info, Vdp2Regs->CHCTLA >> 2, 0x3);
-
-               info.charaddr = (Vdp2Regs->MPOFR & 0x70) * 0x2000;
-               info.paladdr = (Vdp2Regs->BMPNA & 0x7) << 4;
-               info.flipfunction = 0;
-               info.specialfunction = 0;
-            }
-            else
-            {
-               // Tile Mode
-               info.mapwh = 4;
-               ReadPlaneSize(&info, Vdp2Regs->PLSZ >> 12);
-               ReadPatternData(&info, Vdp2Regs->PNCN0, Vdp2Regs->CHCTLA & 0x1);
-            }
-
-            info.PlaneAddr = (void FASTCALL (*)(void *, int))&Vdp2ParameterBPlaneAddr;
-         }
-         else if (Vdp2Regs->BGON & 0x1)
-         {
-            // NBG0 mode
-            info.enable = Vdp2Regs->BGON & 0x1;
-
-            if((info.isbitmap = Vdp2Regs->CHCTLA & 0x2) != 0)
-            {
-               // Bitmap Mode
-
-               ReadBitmapSize(&info, Vdp2Regs->CHCTLA >> 2, 0x3);
-
-               info.charaddr = (Vdp2Regs->MPOFN & 0x7) * 0x20000;
-               info.paladdr = (Vdp2Regs->BMPNA & 0x7) << 4;
-               info.flipfunction = 0;
-               info.specialfunction = 0;
-            }
-            else
-            {
-               // Tile Mode
-               info.mapwh = 2;
-
-               ReadPlaneSize(&info, Vdp2Regs->PLSZ);
-               ReadPatternData(&info, Vdp2Regs->PNCN0, Vdp2Regs->CHCTLA & 0x1);
-            }
-
-            info.PlaneAddr = (void FASTCALL (*)(void *, int))&Vdp2NBG0PlaneAddr;
-         }
-         else
-            return NULL;
-
-         info.transparencyenable = !(Vdp2Regs->BGON & 0x100);
-         info.specialprimode = Vdp2Regs->SFPRMD & 0x3;
-
-         info.colornumber = (Vdp2Regs->CHCTLA & 0x70) >> 4;
-         info.coloroffset = (Vdp2Regs->CRAOFA & 0x7) << 8;
-         break;
-      }
-      case 1: //NBG1
-      {
-         info.enable = Vdp2Regs->BGON & 0x2;
-         info.transparencyenable = !(Vdp2Regs->BGON & 0x200);
-         info.specialprimode = (Vdp2Regs->SFPRMD >> 2) & 0x3;
-
-         info.colornumber = (Vdp2Regs->CHCTLA & 0x3000) >> 12;
-
-         if((info.isbitmap = Vdp2Regs->CHCTLA & 0x200) != 0)
-         {
-            ReadBitmapSize(&info, Vdp2Regs->CHCTLA >> 10, 0x3);
-
-            info.charaddr = ((Vdp2Regs->MPOFN & 0x70) >> 4) * 0x20000;
-            info.paladdr = (Vdp2Regs->BMPNA & 0x700) >> 4;
-            info.flipfunction = 0;
-            info.specialfunction = 0;
-         }
-         else
-         {
-            info.mapwh = 2;
-
-            ReadPlaneSize(&info, Vdp2Regs->PLSZ >> 2);
-
-            ReadPatternData(&info, Vdp2Regs->PNCN1, Vdp2Regs->CHCTLA & 0x100);
-         }
-
-         info.coloroffset = (Vdp2Regs->CRAOFA & 0x70) << 4;
-
-         info.PlaneAddr = (void FASTCALL (*)(void *, int))&Vdp2NBG1PlaneAddr;
-         break;
-      }
-      case 2: //NBG2
-         info.enable = Vdp2Regs->BGON & 0x4;
-         info.isbitmap = 0;
-         info.transparencyenable = !(Vdp2Regs->BGON & 0x400);
-         info.specialprimode = (Vdp2Regs->SFPRMD >> 4) & 0x3;
-
-         info.colornumber = (Vdp2Regs->CHCTLB & 0x2) >> 1; 
-         info.mapwh = 2;
-
-         ReadPlaneSize(&info, Vdp2Regs->PLSZ >> 4);
-         ReadPatternData(&info, Vdp2Regs->PNCN2, Vdp2Regs->CHCTLB & 0x1);
-
-         info.coloroffset = Vdp2Regs->CRAOFA & 0x700;
-
-         info.PlaneAddr = (void FASTCALL (*)(void *, int))&Vdp2NBG2PlaneAddr;
-         break;
-      case 3: //NBG3
-         info.enable = Vdp2Regs->BGON & 0x8;
-         info.isbitmap = 0;
-         info.transparencyenable = !(Vdp2Regs->BGON & 0x800);
-         info.specialprimode = (Vdp2Regs->SFPRMD >> 6) & 0x3;
-
-         info.colornumber = (Vdp2Regs->CHCTLB & 0x20) >> 5;
-	
-         info.mapwh = 2;
-
-         ReadPlaneSize(&info, Vdp2Regs->PLSZ >> 6);
-         ReadPatternData(&info, Vdp2Regs->PNCN3, Vdp2Regs->CHCTLB & 0x10);
-
-         info.coloroffset = (Vdp2Regs->CRAOFA & 0x7000) >> 4;
-         info.PlaneAddr = (void FASTCALL (*)(void *, int))&Vdp2NBG3PlaneAddr;
-         break;
-      case 4: //RBG0
-         info.enable = Vdp2Regs->BGON & 0x10;
-         info.transparencyenable = !(Vdp2Regs->BGON & 0x1000);
-         info.specialprimode = (Vdp2Regs->SFPRMD >> 8) & 0x3;
-
-         info.colornumber = (Vdp2Regs->CHCTLB & 0x7000) >> 12;
-
-         // Figure out which Rotation Parameter we're using
-         switch (Vdp2Regs->RPMD & 0x3)
-         {
-            case 0:
-               // Parameter A
-               info.rotatenum = 0;
-               info.rotatemode = 0;
-               info.PlaneAddr = (void FASTCALL (*)(void *, int))&Vdp2ParameterAPlaneAddr;
-               break;
-            case 1:
-               // Parameter B
-               info.rotatenum = 1;
-               info.rotatemode = 0;
-               info.PlaneAddr = (void FASTCALL (*)(void *, int))&Vdp2ParameterBPlaneAddr;
-               break;
-            case 2:
-               // Parameter A+B switched via coefficients
-            case 3:
-               // Parameter A+B switched via rotation parameter window
-            default:
-               info.rotatenum = 0;
-               info.rotatemode = 1 + (Vdp2Regs->RPMD & 0x1);
-               break;
-         }
-
-         if((info.isbitmap = Vdp2Regs->CHCTLB & 0x200) != 0)
-         {
-            // Bitmap Mode
-            ReadBitmapSize(&info, Vdp2Regs->CHCTLB >> 10, 0x1);
-
-            if (info.rotatenum == 0)
-               // Parameter A
-               info.charaddr = (Vdp2Regs->MPOFR & 0x7) * 0x20000;
-            else
-               // Parameter B
-               info.charaddr = (Vdp2Regs->MPOFR & 0x70) * 0x2000;
-
-            info.paladdr = (Vdp2Regs->BMPNB & 0x7) << 4;
-            info.flipfunction = 0;
-            info.specialfunction = 0;
-         }
-         else
-         {
-            // Tile Mode
-            info.mapwh = 4;
-
-            if (info.rotatenum == 0)
-               // Parameter A
-               ReadPlaneSize(&info, Vdp2Regs->PLSZ >> 8);
-            else
-               // Parameter B
-               ReadPlaneSize(&info, Vdp2Regs->PLSZ >> 12);
-
-            ReadPatternData(&info, Vdp2Regs->PNCR, Vdp2Regs->CHCTLB & 0x100);
-         }
-
-         info.coloroffset = (Vdp2Regs->CRAOFB & 0x7) << 8;
-         break;
-      default:
-         return NULL;
-   }
-   
-   if (info.enable)
-   {
-      // Allocate bitmap and fill
-      if (info.isbitmap)
-      {
-         if (tilenum >= 0)
-            return NULL;
-         w[0] = info.cellw;
-         h[0] = info.cellh;
-         if ((bitmap = (u32 *)malloc(w[0] * h[0] * sizeof(u32))) == NULL)
-            return NULL;
-         ClearTextureToColor(bitmap, transparentcolor, w[0], h[0]);
-         Vdp2DrawScroll(&info, bitmap, w[0], h[0]);
-      }
-      else
-      {
-         if (tilenum >= 0)
-         {
-            w[0] = info.cellw;
-            h[0] = info.cellh;
-         }
-         else
-         {
-            w[0] = info.cellw * info.patternwh * info.pagewh * info.planew * info.mapwh;
-            h[0] = info.cellh * info.patternwh * info.pagewh * info.planeh * info.mapwh;
-         }
-
-         if ((bitmap = (u32 *)malloc(w[0] * h[0] * sizeof(u32))) == NULL)
-            return NULL;
-
-         ClearTextureToColor(bitmap, transparentcolor, w[0], h[0]);
-         Vdp2DrawScroll(&info, bitmap, w[0], h[0]);
-      }
-   }
+   TitanRender(bitmap, Vdp2Regs->CCCTL & 0x200 ? TITAN_BLEND_BOTTOM : TITAN_BLEND_TOP);
 
    return bitmap;
 }
