@@ -28,7 +28,6 @@ extern u32 *dispbuffer;
 
 extern VideoInterface_struct VIDSoft;
 
-void VIDSoftGetScreenSize(int *width, int *height);
+void VIDSoftVdp2DrawScreen(int screen);
+
 #endif
-
-
