@@ -20,8 +20,12 @@
 
 #ifndef CD_HH
 #define CD_HH
+#ifdef HAVE_NTDDCDRM
 #include <ntddcdrm.h>
 #include <ntddscsi.h>
+#else
+#include "fakeddk.h"
+#endif
 #ifdef HAVE_WNASPI32_H
 #include <wnaspi32.h>
 #endif
@@ -31,8 +35,8 @@
 #define CDCORE_ASPI     3
 
 int SPTICDInit(const char *);
-void SPTICDDeInit();
-int SPTICDGetStatus();
+void SPTICDDeInit(void);
+int SPTICDGetStatus(void);
 s32 SPTICDReadTOC(u32 *);
 int SPTICDReadSectorFAD(u32, void *);
 void SPTICDReadAheadFAD(u32);
