@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #ifndef DISASM_H
@@ -22,7 +22,7 @@
 
 #include "custctl.h"
 
-#define DISASM "YabauseDisassembler"
+#define DISASM TEXT("YabauseDisassembler")
 #define DIS_SETDISFUNC          WM_USER+11
 #define DIS_SETENDADDRESS       WM_USER+12
 #define DIS_GOTOADDRESS         WM_USER+13
