@@ -34,9 +34,9 @@ extern "C" {
 #include "../debug.h"
 #include "../m68kcore.h"
 #include "../movie.h"
-#include "snddx.h"
+#include "../snddx.h"
 #include "cheats.h"
-#include "perdx.h"
+#include "../perdx.h"
 #include "cd.h"
 #include "aviout.h"
 #include "cpudebug/yuidebug.h"
@@ -81,6 +81,7 @@ int screenwidth;
 int screenheight;
 int AlreadyStarted;
 
+HINSTANCE y_hInstance;
 HWND YabWin=NULL;
 HMENU YabMenu=NULL;
 HDC YabHDC=NULL;
@@ -160,6 +161,16 @@ NULL
 
 //////////////////////////////////////////////////////////////////////////////
 
+extern "C" 
+{
+   HWND DXGetWindow()
+   {
+      return YabWin;
+   }
+};
+
+//////////////////////////////////////////////////////////////////////////////
+
 void YuiSetVideoAttribute(int type, int val)
 {
    switch (type)
@@ -292,7 +303,7 @@ int YuiSetVideoMode(int width, int height, int bpp, int fullscreen)
       pfd.cAccumBits = pfd.cAccumRedBits + pfd.cAccumGreenBits +
          pfd.cAccumBlueBits + pfd.cAccumAlphaBits;
       pfd.cDepthBits = depthsize;
-      pfd.cStencilBits = 0;
+      pfd.cStencilBits = 8;
 
       SetPixelFormat(YabHDC, ChoosePixelFormat(YabHDC, &pfd), &pfd);
 
@@ -459,7 +470,7 @@ void YuiPause()
    stop = 1;
    while (!stopped) { Sleep(0); }
 #endif
-   ScspMuteAudio();
+   ScspMuteAudio(SCSP_MUTE_SYSTEM);
    paused = 1;
 }
 
@@ -469,7 +480,7 @@ void YuiUnPause()
 {
    if (paused)
    {
-      ScspUnMuteAudio();
+      ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
 #ifdef USETHREADS
       stop = 0;
 #endif
@@ -486,10 +497,10 @@ void YuiTempPause()
    {
       stop = 1;
       while (!stopped) { Sleep(0); }
-      ScspMuteAudio();
+      ScspMuteAudio(SCSP_MUTE_SYSTEM);
    }
 #else
-   ScspMuteAudio();
+   ScspMuteAudio(SCSP_MUTE_SYSTEM);
 #endif
 }
 
@@ -500,11 +511,11 @@ void YuiTempUnPause()
 #ifdef USETHREADS
    if (!paused)
    {
-      ScspUnMuteAudio();
+      ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
       stop = 0;
    }
 #else
-   ScspUnMuteAudio();
+   ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
 #endif
 }
 
@@ -606,6 +617,10 @@ YabauseSetup:
                DestroyMenu(YabMenu);
             return -1;
          }
+         Update_RAM_Search();
+         Update_RAM_Watch();
+         YuiCaptureVideo();
+
          Sleep(0);
       }
 
@@ -1720,7 +1735,7 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
 				break;
             case IDM_EXIT:
             {
-               ScspMuteAudio();
+               ScspMuteAudio(SCSP_MUTE_SYSTEM);
                PostMessage(hWnd, WM_CLOSE, 0, 0);
                break;
             }
@@ -1787,7 +1802,7 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
       case WM_ENTERMENULOOP:
       {
 #ifndef USETHREADS
-         ScspMuteAudio();
+         ScspMuteAudio(SCSP_MUTE_SYSTEM);
 #endif
          for (i = 0; i < 12; i++)
          {
@@ -1854,7 +1869,7 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
       case WM_EXITMENULOOP:
       {
 #ifndef USETHREADS
-         ScspUnMuteAudio();
+         ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
 #endif
          for (i = 0; i < 12; i++)
          {
