@@ -41,6 +41,7 @@
 #include "yui.h"
 #include "bios.h"
 #include "movie.h"
+#include "osdcore.h"
 #ifdef HAVE_LIBSDL
  #if defined(__APPLE__) || defined(GEKKO)
   #include <SDL/SDL.h>
@@ -70,6 +71,10 @@
  #include "profile.h"
 #endif
 
+#if defined(SH2_DYNAREC)
+#include "sh2_dynarec/sh2_dynarec.h"
+#endif
+
 //////////////////////////////////////////////////////////////////////////////
 
 yabsys_struct yabsys;
@@ -227,6 +232,12 @@ int YabauseInit(yabauseinit_struct *init)
    if (init->frameskip)
       EnableAutoFrameSkip();
 
+#ifdef YAB_PORT_OSD
+   OSDChangeCore(init->osdcoretype);
+#else
+   OSDChangeCore(OSDCORE_DEFAULT);
+#endif
+
    if (init->biospath != NULL && strlen(init->biospath))
    {
       if (LoadBios(init->biospath) != 0)
@@ -370,18 +381,18 @@ int YabauseExec(void) {
 	}
 
 	if (FrameAdvanceVariable == Paused){
-		ScspMuteAudio();
+		ScspMuteAudio(SCSP_MUTE_SYSTEM);
 		return(0);
 	}
   
 	if (FrameAdvanceVariable == NeedAdvance){  //advance a frame
 		FrameAdvanceVariable = Paused; //pause next time
-		ScspUnMuteAudio();
+		ScspUnMuteAudio(SCSP_MUTE_SYSTEM);
 		YabauseEmulate();
 	}
 	
 	if (FrameAdvanceVariable == RunNormal ) { //run normally
-		ScspUnMuteAudio();	
+		ScspUnMuteAudio(SCSP_MUTE_SYSTEM);	
 		YabauseEmulate();
 	}
 	return 0;
